.. SUNCASA Documentation master file, created by
   sphinx-quickstart on some date.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to SUNCASA's Documentation
===================================

Introduction
------------

Welcome to the documentation for SUNCASA, a Python library dedicated to processing and analyzing solar radio observational data.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   api_reference
   contributing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
